==> vue-dynamic-scroller-2.8.0.tgz: package/lib/pc.js <==
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/dynamic-scroller/vue";
import { defineComponent, props, setup as _setup, emitter } from "@dftvue2-opentiny/vue-common";
import RecycleScroller from "@dftvue2-opentiny/vue-recycle-scroller";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  inheritAttrs: false,
  emits: ["resize", "visible"],
  props: [].concat(props, ["items", "keyField", "direction", "listTag", "itemTag", "minItemSize"]),
  components: {
    TinyRecycleScroller: RecycleScroller
  },
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api,
      extendOptions: {
        emitter
      }
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("tiny-recycle-scroller", _vm._b({
    ref: "scroller",
    staticClass: "tiny-dynamic-scroller",
    attrs: {
      "items": _vm.state.itemsWithSize,
      "min-item-size": _vm.minItemSize,
      "direction": _vm.direction,
      "key-field": _vm.keyField,
      "list-tag": _vm.listTag,
      "item-tag": _vm.itemTag
    },
    on: {
      "resize": _vm.onScrollerResize,
      "visible": _vm.onScrollerVisible
    },
    scopedSlots: _vm._u([{
      key: "default",
      fn: function fn(_ref) {
        var itemWithSize = _ref.item, index = _ref.index, active = _ref.active;
        return [_vm._t("default", null, null, {
          item: itemWithSize.item,
          index,
          active,
          itemWithSize
        })];
      }
    }, {
      key: "before",
      fn: function fn() {
        return [_vm._t("before")];
      },
      proxy: true
    }, {
      key: "after",
      fn: function fn() {
        return [_vm._t("after")];
      },
      proxy: true
    }, {
      key: "empty",
      fn: function fn() {
        return [_vm._t("empty")];
      },
      proxy: true
    }], null, true)
  }, "tiny-recycle-scroller", _vm.$attrs, false));
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-dynamic-scroller-2.22.1.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/dynamic-scroller/vue';
import { defineComponent, props, setup, emitter } from '@opentinyvue/vue-common';
import RecycleScroller from '@opentinyvue/vue-recycle-scroller';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  inheritAttrs: false,
  emits: ["resize", "visible"],
  props: [].concat(props, ["items", "keyField", "direction", "listTag", "itemTag", "minItemSize"]),
  components: {
    TinyRecycleScroller: RecycleScroller
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api,
      extendOptions: {
        emitter
      }
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("tiny-recycle-scroller", _vm._b({
    ref: "scroller",
    staticClass: "tiny-dynamic-scroller",
    attrs: {
      "items": _vm.state.itemsWithSize,
      "min-item-size": _vm.minItemSize,
      "direction": _vm.direction,
      "key-field": _vm.keyField,
      "list-tag": _vm.listTag,
      "item-tag": _vm.itemTag
    },
    on: {
      "resize": _vm.onScrollerResize,
      "visible": _vm.onScrollerVisible
    },
    scopedSlots: _vm._u([{
      key: "default",
      fn: function fn(_ref) {
        var itemWithSize = _ref.item, index = _ref.index, active = _ref.active;
        return [_vm._t("default", null, null, {
          item: itemWithSize.item,
          index,
          active,
          itemWithSize
        })];
      }
    }, {
      key: "before",
      fn: function fn() {
        return [_vm._t("before")];
      },
      proxy: true
    }, {
      key: "after",
      fn: function fn() {
        return [_vm._t("after")];
      },
      proxy: true
    }, {
      key: "empty",
      fn: function fn() {
        return [_vm._t("empty")];
      },
      proxy: true
    }], null, true)
  }, "tiny-recycle-scroller", _vm.$attrs, false));
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
